<!--案件处置处理表单弹出层-->
<template>
  <van-popup
    v-model="isShowPopup"
    :close-on-click-overlay="false"
    position="right"
    @closed="popupClosed"
    :style="{ width:'100%',height: '100%' }"
  >
    <div class="query-search-popup">
      <!--  头部  -->
      <van-sticky>
        <van-nav-bar
          :title=" '案件处置处理'"
        />
      </van-sticky>
      <van-form
        scroll-to-error
        label-width="80px"
        @submit="onSubmit"
        @failed="onFailed"
        ref="vanForm"
      >
        <van-field
          name="simpleHandleType"
          label="处理类型"
          input-align="right"
          v-model="formData.simpleHandleType"
          placeholder="请选择处理类型"
          required
          :rules="[{required: true}]"
          readonly
          clickable
          @click="simpleHandleTypePicker = true"
        />
        <van-field
          name="rectifyContent"
          label="整改内容"
          input-align="right"
          rows="2"
          autosize
          placeholder="请输入整改内容"
          type="textarea"
          required
          :rules="[{required: true}]"
          v-model="formData.rectifyContent"
        />
        <van-field
          name="rectifyTime"
          label="整改时限"
          input-align="right"
          placeholder="请输入整改时限"
          v-model="formData.rectifyTime"
          readonly
          clickable
          required
          :rules="[{required: true}]"
          @click="rectifyTimePicker = true"
        />
        <van-field
          name="rectifyDemand"
          label="整改要求"
          label-width="100px"
          input-align="right"
          v-model="formData.rectifyDemand"
          rows="2"
          autosize
          type="textarea"
          placeholder="请输入整改要求"
        />
        <van-field
          name="undoneOpinion"
          label="对未完成的处理意见"
          input-align="right"
          v-model="formData.undoneOpinion"
          rows="2"
          autosize
          type="textarea"
          label-width="120px"
          placeholder="请输入对未完成的处理意见"
        />
        <van-field
          name="rectifyResult"
          label="整改效果"
          input-align="right"
          v-model="formData.rectifyResult"
          rows="2"
          autosize
          type="textarea"
          placeholder="请输入整改效果"
        />
        <van-field label="处置结果附件图片" label-width="100px" name="handleFileArr">
          <template #input>
            <van-uploader
              v-model="formData.handleFileArr"
              :before-read="beforeRead"
              :after-read="afterRead"
              :before-delete="beforeDelete"
            />
          </template>
        </van-field>

        <div class="footer">
          <van-button class="btn-left" plain native-type="button" @click="cancel(true)" :loading="loading">
            取消
          </van-button>
          <van-button class="btn-right" block type="info" :loading="loading">
            案件处理
          </van-button>
        </div>
      </van-form>

      <!--  选择器  -->
      <template>
        <!--   处理类型   -->
        <van-popup v-model="simpleHandleTypePicker" position="bottom">
          <van-picker
            title="处理类型"
            show-toolbar
            value-key="name"
            :columns="simpleHandleTypeOpt"
            @confirm="
            ({name}) => {
              formData.simpleHandleType = name
              simpleHandleTypePicker = false
            }
          "
            @cancel="simpleHandleTypePicker = false"
          />
        </van-popup>
        <!--   整改时限   -->
        <van-popup v-model="rectifyTimePicker" position="bottom">
          <van-datetime-picker
            title="选择整改时限"
            type="datetime"
            :min-date=" new Date()"
            @cancel="rectifyTimePicker = false"
            @confirm="time => {
              this.formData.rectifyTime = moment(time).format('YYYY-MM-DD HH:mm:ss');
              rectifyTimePicker = false
            }"
          />
        </van-popup>
      </template>
    </div>
  </van-popup>
</template>

<script>
import moment from 'moment'
import {Dialog, Toast} from 'vant'
import {fileUpload} from '@/api/Mobile/caseHandling'

export default {
  name: 'DispositionPopup', // 案件处置处理表单弹出层
  props: {
    // 是否展示弹层
    isShow: {
      default: false,
      type: Boolean
    },
    //  按钮Loading状态
    loading: {
      default: false,
      type: Boolean
    },
    // 案件类型
    simpleHandleTypeOpt: {
      default: () => ([]),
      type: Array
    }
  },
  data() {
    return {
      formData: {
        handleFile: [],
        handleFileArr: []
      },
      simpleHandleTypePicker: false,
      rectifyTimePicker: false  // 整改时限显隐
    }
  },
  computed: {
    isShowPopup: {
      get() {
        return this.isShow
      },
      set(val) {
        this.$emit('update:isShow', val)
      }
    },
    loadingProps: {
      get() {
        return this.loading
      },
      set(val) {
        this.$emit('update:loading', val)
      }
    }
  },
  methods: {
    moment,

    // 弹层关闭
    popupClosed() {
      this.resetData()
    },

    /**
     * 取消按钮
     * @param {Boolean} isConfirm 是否显示确认提示框
     * @returns void
     * */
    cancel(isConfirm = false) {
      // 重置表单函数
      const resetForm = _ => {
        this.$refs.vanForm.resetValidation()
        this.formData = this.$options.data().formData
        this.isShowPopup = false
      }

      if (!isConfirm) return resetForm()

      Dialog.confirm({
        title: '',
        message: '退出案件处置登记，不会保存登记信息'
      }).then(_ => resetForm())
        .catch(_ => _)
    },


    // 表单验证成功
    onSubmit(formData) {
      const {handleFile} = this.formData
      this.$emit('onSubmit', {
        ...formData,
        handleFile,
        handleType: 1,
        caseStatus: '3'
      })
    },

    // 表单验证失败
    onFailed({errors}) {
      if (errors.length) {
        Toast.fail(`有${errors.length}个字段未通过校验，请正确填写表单内容。`)
      }
    },

    // 重置数据
    resetData() {
      this.formData = this.$options.data().formData
    },

    // 文件读取前
    beforeRead(file) {
      const isJPG =
        file.type === 'image/jpeg' ||
        file.type === 'image/png' ||
        file.type === 'image/jpg'
      const isLt1M = file.size / 1024 / 1024 < 10
      if (!isJPG) {
        Toast.fail('上传图片只能是 JPG 格式!')
      }
      if (!isLt1M) {
        Toast.fail('上传图片大小不能超过 1MB!')
      }
      return isJPG && isLt1M
    },

    // 文件读取后
    async afterRead(file) {
      if (this.loadingProps) {
        Toast.fail('上传文件中...请上传后重试')
        this.formData.handleFileArr.pop()
      }
      this.loadingProps = true
      const {fileId, success} = await fileUpload({
        files: file.file,
        bizCode: 'Image'
      })
      if (success && fileId) {
        file.fileId = fileId
        this.formData.handleFile.push(fileId)
      } else {
        Toast.fail('上传失败')
        this.formData.handleFileArr.pop()
      }
      this.loadingProps = false
    },

    //  文件删除后
    beforeDelete(file) {
      if (this.loadingProps) {
        Toast.fail('上传文件中...请上传后重试')
        return false
      }
      const index = this.formData.handleFile.findIndex(
        fileId => fileId === file.fileId
      )
      this.formData.handleFile.splice(index, 1)
      return true
    }
  }
}
</script>

<style lang="scss" scoped>
.query-search-popup {
  display: flex;
  flex-direction: column;
  height: 100%;

  ::v-deep .van-form {
    flex: 1;
    position: relative;

    .footer {
      display: flex;
      justify-content: center;
      position: absolute;
      bottom: 5%;
      width: 100%;


      .van-button {
        width: 40%;

        &:first-child {
          border-radius: 100px 0 0 100px;
          border-color: #999;
          border-width: 8px;
          border-right: 0;
        }

        &:last-child {
          border-radius: 0 100px 100px 0;
        }
      }
    }
  }

}
</style>

